@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-
 import argparse
 import json
 import os
@@ -100,9 +98,14 @@ def to_docstring(wrapped_text, level=1):
         suffix = '\n' + prefix
 
     wrapped_text[0] = wrapped_text[0].lstrip()
+    body = '\n'.join(wrapped_text)
+    if not suffix and body[-1] == "'":
+        # otherwise it becomes: '''' (EOL while scanning string literal)
+        suffix = ' '
+
     return '%s\'\'\'%s%s\'\'\'\n' % (
         prefix,
-        '\n'.join(wrapped_text),
+        body,
         suffix,
     )
 
@@ -352,7 +355,7 @@ class %(name)s(sgqlc.types.Enum):
             'name': name,
             'schema_name': self.schema_name,
             'docstrings': self.get_enum_docstring(t),
-            'choices': tuple(v['name'] for v in t['enumValues']),
+            'choices': tuple(sorted(v['name'] for v in t['enumValues'])),
         })
         self.written_types.add(name)
 
